<?php

/*
 * Copyright (C) 2017 Puiu Calin
 * This program is a commercial software: is forbidden to use this software without licence, 
 * on multiple installations, and by purchasing from other source than those authorized for the sale of software.
 * Unauthorized copying of this file, via any medium is strictly prohibited
 */

class CbK_Avatar extends DAO {

    private static $instance;

    public static function newInstance() {
        if (!self::$instance instanceof self) {
            self::$instance = new self;
        }
        return self::$instance;
    }

    function __construct() {
        parent::__construct();
    }

    //sql import
    public function import($file) {
        $path = osc_plugin_resource($file);
        $sql = file_get_contents($path);
        if (!$this->dao->importSQL($sql)) {
            throw new Exception("Error importSQL::CbK Avatar<br>" . $file);
        }
    }

    public function install() {
        $this->import('cbk_avatar/include/sql.sql');
        osc_set_preference('CbKAvatar_Version', CbKAvatar_Version, 'cbk_avatar');
        osc_set_preference('max_size', cbk_avatar_size_on_install(), 'cbk_avatar');
        osc_set_preference('small_dimension', '50x50', 'cbk_avatar');
        osc_set_preference('other_dimensions', '1', 'cbk_avatar');
        osc_set_preference('thumb_dimension', '100x100', 'cbk_avatar');
        osc_set_preference('normal_dimension', '200x200', 'cbk_avatar');
        osc_set_preference('admin_welcome', '0', 'cbk_avatar');
        osc_set_preference('auto_embed', '0', 'cbk_avatar');
        $directory = osc_base_path() . 'oc-content/plugins/cbk_avatar/users/';
        if (!file_exists($directory)) {
            mkdir($directory, 0755, true);
        }
    }

    public function uninstall() {
        $this->dao->query(sprintf('DROP TABLE %s', $this->getTableAvatar()));
        //delete the images from user folder
        $directory = osc_base_path() . 'oc-content/plugins/cbk_avatar/users/';
        cbk_avatar_delete_folder($directory);
    }

    public function getTableAvatar() {
        return DB_TABLE_PREFIX . 't_cbk_avatar';
    }

    public function user_image($user_id) {
        $this->dao->select();
        $this->dao->from($this->getTableAvatar());
        $this->dao->where('user_id', $user_id);
        $result = $this->dao->get();
        if (!$result->row()) {
            return NULL;
        }
        return $result->row();
    }

    public function save_image_data($user_id, $file_ext, $file_tmp) {
        //make user folder if not exists
        $directory = osc_base_path() . 'oc-content/plugins/cbk_avatar/users/';
        if (!file_exists($directory)) {
            mkdir($directory, 0755, true);
        }
        $error = 0;
        $result = $this->user_image($user_id);
        $c_path = floor($user_id / 100);
        $folder = cbk_image_folder_path() . '/' . $c_path . '/';
        if (!is_dir($folder)) {
            if (!@mkdir($folder, 0755, true)) {
                $error = 1; // PATH CAN NOT BE CREATED
            }
        }
        if (empty($result)) {
            $this->dao->insert($this->getTableAvatar(), array('user_id' => $user_id, 'file_extension' => $file_ext, 'c_path' => $c_path));
        } else {
            $this->dao->update($this->getTableAvatar(), array('file_extension' => $file_ext), array('id' => $result['id']));
            //if update first delete the old images, only if difrent extension
            //avoid multiple images with different extensions
            if ($result['file_extension'] != $file_ext) {
                $this->delete_old_image($result, $user_id);
            }
        }
        //upload image
        $this->upload_file($user_id, $file_tmp, $folder, $file_ext);
    }

    public function upload_file($user_id, $file_tmp, $folder, $file_extension = NULL, $original = NULL) {
        $image_name = 'profile' . $user_id;
        $file_destination = $folder . $image_name . '.' . $file_extension;
        if ($original) {
            // do not resize image
            move_uploaded_file($file_tmp, $file_destination);
        } else {
            //resize image
            $size = cbk_avatar_image_dimension_small();
            $imgres = ImageProcessing::fromFile($file_tmp);
            $img_rot = $imgres->autoRotate();
            $img = $img_rot->resizeTo($size[0], $size[1]);
            $img->saveToFile($file_destination, $file_extension);
            //save other dimensions of image
            if (cbk_avatar_other_dimensions_image()) {
                //thumb save
                $size1 = cbk_avatar_image_dimension_thumb();
                $file_destination = $folder . $image_name . '_thumbnail.' . $file_extension;
                ImageProcessing::fromFile($file_tmp)->resizeTo($size1[0], $size1[1])->saveToFile($file_destination, $file_extension);
                //normal save
                $size2 = cbk_avatar_image_dimension_normal();
                $file_destination = $folder . $image_name . '_normal.' . $file_extension;
                ImageProcessing::fromFile($file_tmp)->resizeTo($size2[0], $size2[1])->saveToFile($file_destination, $file_extension);
            }
        }
    }

    public function delete_image($user_id) {
        $image_data = $this->user_image($user_id);
        $image_path = cbk_image_folder_path() . '/' . $image_data['c_path'] . '/profile' . $user_id . '.' . $image_data['file_extension'];
        if (@unlink($image_path)) {
            //delete other dimensions images
            @unlink(cbk_image_folder_path() . '/' . $image_data['c_path'] . '/profile' . $user_id . '_thumbnail.' . $image_data['file_extension']);
            @unlink(cbk_image_folder_path() . '/' . $image_data['c_path'] . '/profile' . $user_id . '_normal.' . $image_data['file_extension']);
            //delete record from database
            return $this->dao->delete($this->getTableAvatar(), array('id' => $image_data['id']));
        }
    }

    public function delete_old_image($image_data, $user_id) {
        @unlink(cbk_image_folder_path() . '/' . $image_data['c_path'] . '/profile' . $user_id . '.' . $image_data['file_extension']);
        @unlink(cbk_image_folder_path() . '/' . $image_data['c_path'] . '/profile' . $user_id . '_thumbnail.' . $image_data['file_extension']);
        @unlink(cbk_image_folder_path() . '/' . $image_data['c_path'] . '/profile' . $user_id . '_normal.' . $image_data['file_extension']);
    }

    public function admin_upload_no_image($file_tmp, $file_extension, $original = NULL) {
        $folder = osc_plugin_path('cbk_avatar/images/');
        $image_name = 'no_image';
        if ($original) {
            // do not resize image
            $file_destination = $folder . 'no_image_original.' . $file_extension;
            move_uploaded_file($file_tmp, $file_destination);
        } else {
            $curent_image_extension = osc_get_preference('no_image_extension', 'cbk_avatar');
            if (!empty($curent_image_extension) && $file_extension != $curent_image_extension) {
                //first delete the curent images
                @unlink($folder . 'no_image.' . $curent_image_extension);
                @unlink($folder . 'no_image_thumbnail.' . $curent_image_extension);
                @unlink($folder . 'no_image_normal.' . $curent_image_extension);
            }

            //resize image
            $size = cbk_avatar_image_dimension_small();
            $file_destination = $folder . $image_name . '.' . $file_extension;
            $imgres = ImageProcessing::fromFile($file_tmp);
            $img_rot = $imgres->autoRotate();
            $img = $img_rot->resizeTo($size[0], $size[1]);
            $img->saveToFile($file_destination, $file_extension);
            //thumb save
            $size1 = cbk_avatar_image_dimension_thumb();
            $file_destination = $folder . $image_name . '_thumbnail.' . $file_extension;
            ImageProcessing::fromFile($file_tmp)->resizeTo($size1[0], $size1[1])->saveToFile($file_destination, $file_extension);
            //normal save
            $size2 = cbk_avatar_image_dimension_normal();
            $file_destination = $folder . $image_name . '_normal.' . $file_extension;
            ImageProcessing::fromFile($file_tmp)->resizeTo($size2[0], $size2[1])->saveToFile($file_destination, $file_extension);
        }
        //save file extension
        osc_set_preference('no_image_extension', $file_extension, 'cbk_avatar');
    }

    //stats user image
    public function count_all_records() {
        $this->dao->select("COUNT(*) as total");
        $this->dao->from($this->getTableAvatar());
        $result = $this->dao->get();
        if ($result == false || $result->numRows() == 0) {
            return 0;
        }
        $row = $result->row();
        return $row['total'];
    }

    //count al regitered users
    public function count_registered_users() {
        $this->dao->select("COUNT(*) as i_total");
        $this->dao->from(DB_TABLE_PREFIX . 't_user');
        $result = $this->dao->get();
        if ($result == false || $result->numRows() == 0) {
            return 0;
        }
        $row = $result->row();
        return $row['i_total'];
    }

}